from distutils.core import setup

setup(
    name = 'janetlist', 
    version  = '1.1.2',
    py_modules = ['janetlist'],
    author = 'ZhangPeng',
    author_email = '444327149@qq.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
    )


